marktools.detach_marks_attached_to_component
============================================

.. autofunction:: abjad.tools.marktools.detach_marks_attached_to_component.detach_marks_attached_to_component
